@@ -1,11 +1,9 @@
 use lambda_http::{
     handler,
-    lambda_runtime::{self, Context},
+    lambda_runtime::{self, Context, Error},
     IntoResponse, Request, RequestExt, Response,
 };
 
-type Error = Box<dyn std::error::Error + Send + Sync + 'static>;
-
 #[tokio::main]
 async fn main() -> Result<(), Error> {
     lambda_runtime::run(handler(func)).await?;
